from blaxel.common.internal import get_alphanumeric_limited_hash

print(get_alphanumeric_limited_hash("charlou-function-blaxel-search", 48))

print(get_alphanumeric_limited_hash("main-function-explorer-mcp", 48))